from moksha.pastetemplate import MokshaLiveWidgetTemplate
import os, shutil
import pkg_resources
from paste.deploy import loadapp
from webtest import TestApp
from paste.script.create_distro import CreateDistroCommand
from moksha.commands.quickstart import MokshaQuickstartCommand

testDataPath = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'data')

class Options(object):
    simulate = False
    overwrite = True
    templates = ['moksha.master', 'moksha.livewidget']
    output_dir = testDataPath
    list_templates = False
    list_variables = False
    config = None
    inspect_files = False
    svn_repository = False


class TestQuickStart(object):

    def __init__(self,**options):
        self.app = None
        self.template_vars = {
                'package': 'MokshaTest',
                'project': 'mokshatest',
                'egg': 'MokshaTest',
                'egg_plugins': ['Moksha'],
                'topic': 'moksha.topics.test',
        }

    def setUp(self):
        command = CreateDistroCommand('MokshaQuickStartUnitTest')
        command.verbose = False
        command.simulate = False
        command.options = Options()
        command.interactive=False
        command.args=[
                'MokshaTest', '--package=mokshatest'
                # TODO: do individual tests for each template
                '--template=moksha.master',
                #'--template=moksha.livewidget',
                #'--template=moksha.stream', '--template=moksha.consumer',
                'livewidget=True',
                'widget_name=MokshaTestWidget',
                'stream=False',
                'stream_name=MokshaTestStream',
                'consumer=False',
                'consumer_name=MokshaTestConsumer',
                ]

        proj_dir = os.path.join(testDataPath, 'MokshaTest')
        command.create_template(
                MokshaLiveWidgetTemplate('MokshaTest'),
                proj_dir,
                self.template_vars)
        command.command()

        pkg_resources.working_set.add_entry(proj_dir)

        cwd = os.getcwd()
        os.chdir(proj_dir)
        print "Going to %s and running paver egg_info" % proj_dir
        os.system('paver -h')
        os.system('bash')
        os.chdir(cwd)

        self.app = loadapp('config:/srv/moksha/development.ini',
                           relative_to=proj_dir)
        self.app = TestApp(self.app)


    def tearDown(self):
        shutil.rmtree(testDataPath, ignore_errors=True)

    def test_index(self):
        resp = self.app.get('/')
        assert '[ Moksha ]' in resp

    #def test_jquery_injection(self):
    #    """ Ensure jQuery is getting injected on our main dashboard """
    #    resp = self.app.get('/')
    #    assert 'jquery' in resp

    #def test_global_resources(self):
    #    """ Ensure we are getting our global resources injected """
    #    resp = self.app.get('/')
    #    assert 'moksha_csrf_token' in resp

    #def test_menu(self):
    #    """ Ensure that our default menu is being created """
    #    resp = self.app.get('/')
    #    assert 'buildMenu' in resp

    #def test_tcpsocket(self):
    #    """ Ensure our Orbited TCPSocket is getting injected """
    #    resp = self.app.get('/')
    #    assert 'TCPSocket' in resp

    #def test_livewidget(self):
    #    """ Ensure our LiveWidget is available """
    #    resp = self.app.get('/widgets/MokshaTestWidget')
    #    assert False, resp.body


if __name__ == '__main__':
    import nose
    cls = TestQuickStart()
    cls.setUp()
    testspath = os.path.join(testDataPath,'MokshaTest','mokshatest','tests')
    nose.main(argv=['-w',testspath],exit=False)
    cls.tearDown()
